@@ -100,6 +100,8 @@ class Catalog:
         languages: Union[str, list] = None,
         license: str = None,
         page: int = 1,
+        elg_compatible_service: bool = None,
+        elg_hosted_data: bool = None,
     ):
         """Internal method to send one search request to the API.
 
@@ -108,8 +110,8 @@ class Catalog:
                 'Project'. Defaults to None.
             search (str, optional): terms to use for the search request. Defaults to None.
             resource (str, optional): type of the language resource. Only used when the entity is set to
-                'LanguageResource'. Can be 'Tool/Service', 'Lexical/Conceptual resource', 'Corpus', or
-                'Language description'. Defaults to None.
+                'LanguageResource'. Can be 'Tool/Service', 'Lexical/Conceptual resource', 'Corpus', 'Model', 'Grammar', or
+                'Uncategorized Language Description'. Defaults to None.
             function (str, optional): type of the function of the service. Only used when resource set to 'Tool/Service'.
                 Defaults to None.
             languages (Union[str, list], optional): language filter for the search request. Can be a string or
@@ -117,6 +119,8 @@ class Catalog:
                 and not one among all. The full name or the ISO639 code of the language can be used. Defaults to None.
             license (str, optional): license filter. Defaults to None.
             page (int, optional): page number. Defaults to 1.
+            elg_compatible_service (bool, optional): Filter ELG compatible services. Defaults to None.
+            elg_hosted_data (bool, optional): Filter ELG hosted data. Defaults to None.
 
         Returns:
             List[elg.Entity]: list of the results.
@@ -139,28 +143,34 @@ class Catalog:
                 queries.append(("language__term", ISO639.LanguageName(language)))
         if license:
             queries.append(("licence__term", license))
+        if elg_compatible_service:
+            queries.append(("elg_integrated_services_and_data__term", "ELG compatible services"))
+        if elg_hosted_data:
+            queries.append(("elg_integrated_services_and_data__term", "ELG hosted data"))
         response = self._get(path=path, queries=queries, json=True)
         return [Entity.from_search_result(result=result, domain=self.domain) for result in response["results"]]
 
     def search(
         self,
-        entity: str = "LanguageResource",
+        entity: str = None,
         search: str = None,
         resource: str = None,
         function: str = None,
         languages: Union[str, list] = None,
         license: str = None,
         limit: int = 100,
+        elg_compatible_service: bool = False,
+        elg_hosted_data: bool = False,
     ):
         """Generator to iterate through search results via the API.
 
         Args:
             entity (str, optional): type of the entity to search. Can be 'LanguageResource', 'Organization', or
-                'Project'. Defaults to "LanguageResource".
+                'Project'. Defaults to None.
             search (str, optional): terms to use for the search request. Defaults to None.
             resource (str, optional): type of the language resource. Only used when the entity is set to
-                'LanguageResource'. Can be 'Tool/Service', 'Lexical/Conceptual resource', 'Corpus', or
-                'Language description'. Defaults to None.
+                'LanguageResource'. Can be 'Tool/Service', 'Lexical/Conceptual resource', 'Corpus', 'Model', 'Grammar', or
+                'Uncategorized Language Description'. Defaults to None.
             function (str, optional): type of the function of the service. Only used when resource set to 'Tool/Service'.
                 Defaults to None.
             languages (Union[str, list], optional): language filter for the search request. Can be a string or
@@ -168,6 +178,8 @@ class Catalog:
                 and not one among all. The full name or the ISO639 code of the language can be used. Defaults to None.
             license (str, optional): license filter. Defaults to None.
             limit (int, optional): limit number of results. Defaults to 100.
+            elg_compatible_service (bool, optional): Filter ELG compatible services. Defaults to False.
+            elg_hosted_data (bool, optional): Filter ELG hosted data. Defaults to False.
 
         Yields:
             elg.Entity: search results one entity at a time.
@@ -187,8 +199,8 @@ class Catalog:
                 limit = 100,
             )]
         """
-        # results = []
-        finished = False
+        if elg_compatible_service and elg_hosted_data:
+            raise ValueError("elg_compatible_service and elg_hosted_data cannot be both True.")
         page = 1
         attempts_remaining = 100
         yielded = 0
@@ -202,6 +214,8 @@ class Catalog:
                     languages=languages,
                     license=license,
                     page=page,
+                    elg_compatible_service=elg_compatible_service,
+                    elg_hosted_data=elg_hosted_data,
                 )
             except ConnectException as e:
                 if attempts_remaining == 0:
@@ -233,6 +247,8 @@ class Catalog:
         function: str = None,
         languages: Union[str, list] = None,
         license: str = None,
+        elg_compatible_service: bool = None,
+        elg_hosted_data: bool = None,
     ):
         """
         Method to search resources interactivly. Warn: not well coded and tested.
@@ -247,6 +263,8 @@ class Catalog:
                 languages=languages,
                 license=license,
                 page=page,
+                elg_compatible_service=elg_compatible_service,
+                elg_hosted_data=elg_hosted_data,
             )
             self._display_entities(results)
             choice = self._make_choice(results)
