@@ -18,6 +18,10 @@ def docker_create_command_factory(args):
         commands=args.commands,
         base_image=args.base_image,
         service_type=args.service_type,
+        log_level=args.log_level,
+        workers=args.workers,
+        timeout=args.timeout,
+        worker_class=args.worker_class,
     )
 
 
@@ -94,6 +98,36 @@ class DockerCreateCommand(BaseELGCommand):
             help="Type of service used. Can be 'flask' or 'quart'.",
             choices=["flask", "quart"],
         )
+        info_parser.add_argument(
+            "--log_level",
+            type=str,
+            default="INFO",
+            required=None,
+            help="The minimum severity level from which logged messages should be displayed.",
+            choices=["INFO", "DEBUG", "TRACE"],
+        )
+        info_parser.add_argument(
+            "--workers",
+            type=int,
+            default=1,
+            required=None,
+            help="Number of Gunicorn workers. Only used for the FlaskService class.",
+        )
+        info_parser.add_argument(
+            "--timeout",
+            type=int,
+            default=30,
+            required=None,
+            help="Timeout value for the Gunicorn worker. Only used for the FlaskService class.",
+        )
+        info_parser.add_argument(
+            "--worker_class",
+            type=str,
+            default="sync",
+            required=None,
+            help="Worker class value for the Gunicorn worker. Only used for the FlaskService class.",
+            choices=["sync", "gthread"],
+        )
 
         info_parser.set_defaults(func=docker_create_command_factory)
 
@@ -108,6 +142,10 @@ class DockerCreateCommand(BaseELGCommand):
         commands: Union[str, List[str]] = None,
         base_image: str = None,
         service_type: str = "flask",
+        log_level: str = "INFO",
+        workers: int = 1,
+        timeout: int = 30,
+        worker_class: str = "sync",
     ):
         self._classname = classname
         self._path = path
@@ -118,6 +156,10 @@ class DockerCreateCommand(BaseELGCommand):
         self._commands = commands
         self._base_image = base_image
         self._service_type = service_type
+        self._log_level = log_level
+        self._workers = workers
+        self._timeout = timeout
+        self._worker_class = worker_class
 
     def run(self):
         if self._service_type == "flask":
@@ -168,6 +210,10 @@ class DockerCreateCommand(BaseELGCommand):
                     commands=commands,
                     base_image=self._base_image,
                     path=self._path,
+                    log_level=self._log_level,
+                    workers=self._workers,
+                    timeout=self._timeout,
+                    worker_class=self._worker_class,
                 )
             elif self._service_type == "quart":
                 QuartService.create_docker_files(
@@ -176,6 +222,7 @@ class DockerCreateCommand(BaseELGCommand):
                     commands=commands,
                     base_image=self._base_image,
                     path=self._path,
+                    log_level=self._log_level,
                 )
         except Exception as e:
             logger.error(f"Error during the creation of docker files - {e}")
