@@ -8,6 +8,7 @@ from .. import __version__
 from .docker import DockerCommand
 from .download import DownloadCommand
 from .info import InfoCommand
+from .local_installation import LocalInstallationCommand
 from .run import RunCommand
 from .search import SearchCommand
 
@@ -27,6 +28,7 @@ def main():
     InfoCommand.register_subcommand(commands_parser)
     SearchCommand.register_subcommand(commands_parser)
     DockerCommand.register_subcommand(commands_parser)
+    LocalInstallationCommand.register_subcommand(commands_parser)
 
     args = parser.parse_args()
 
