@@ -18,7 +18,7 @@ except:
     )
 
 
-from .model import (AudioRequest, Failure, Progress, ResponseObject,
+from .model import (AudioRequest, Failure, Progress, Request, ResponseObject,
                     StandardMessages, StructuredTextRequest, TextRequest)
 from .utils.docker import COPY_FOLDER, DOCKERFILE, ENTRYPOINT_FLASK, ENV_FLASK
 from .utils.json_encoder import json_encoder
@@ -115,12 +115,19 @@ class FlaskService:
         request_type = data.get("type")
         logger.debug("Data type: {request_type}", request_type=request_type)
         if request_type in ["audio", "text", "structuredText"]:
-            if request_type == "audio":
-                request = AudioRequest(**data)
-            elif request_type == "text":
-                request = TextRequest(**data)
-            else:
-                request = StructuredTextRequest(**data)
+            try:
+                if request_type == "audio":
+                    request = AudioRequest(**data)
+                elif request_type == "text":
+                    request = TextRequest(**data)
+                else:
+                    request = StructuredTextRequest(**data)
+            except Exception as e:
+                response = Failure(errors=[StandardMessages.generate_elg_request_invalid()])
+        else:
+            response = Failure(errors=[StandardMessages.generate_elg_request_invalid()])
+
+        if isinstance(request, Request):
             logger.trace("Call with the input: {request}", request=request)
             try:
                 response = self.process_request(request)
@@ -129,8 +136,6 @@ class FlaskService:
                 response = Failure(
                     errors=[StandardMessages.generate_elg_service_internalerror(params=[str(sys.exc_info()[1])])]
                 )
-        else:
-            response = Failure(errors=[StandardMessages.generate_elg_request_invalid()])
 
         if isinstance(response, Failure):
             logger.debug("Get error message")
