@@ -1,3 +1,5 @@
+from typing import Any
+
 from pydantic import BaseModel
 
 from .StatusMessage import StatusMessage
@@ -17,3 +19,8 @@ class Progress(BaseModel):
 
     class Config:
         alias_generator = to_camel
+
+    def json(self, **kwargs: Any) -> str:
+        if "exclude_none" not in kwargs.keys():
+            kwargs["exclude_none"] = True
+        return super().json(**kwargs)
