@@ -1,3 +1,5 @@
+from typing import Any
+
 from pydantic import BaseModel
 
 from .utils import to_camel
@@ -26,3 +28,8 @@ class Request(BaseModel):
     def __str__(self):
         """Override string to display dictionary"""
         return " - ".join([f"{k}: {v}" for k, v in self.dict().items() if v is not None])
+
+    def json(self, **kwargs: Any) -> str:
+        if "exclude_none" not in kwargs.keys():
+            kwargs["exclude_none"] = True
+        return super().json(**kwargs)
