@@ -1,4 +1,4 @@
-from typing import Dict, List
+from typing import Any, Dict, List
 
 from pydantic import BaseModel
 
@@ -29,3 +29,8 @@ class StatusMessage(BaseModel):
 
     class Config:
         alias_generator = to_camel
+
+    def json(self, **kwargs: Any) -> str:
+        if "exclude_none" not in kwargs.keys():
+            kwargs["exclude_none"] = True
+        return super().json(**kwargs)
