@@ -2,6 +2,6 @@ from .Annotation import Annotation
 from .Failure import Failure
 from .Progress import Progress
 from .Request import Request
-from .Response import Response
 from .ResponseObject import ResponseObject
+from .StandardMessages import StandardMessages
 from .StatusMessage import StatusMessage
