@@ -1,37 +1,49 @@
+from numbers import Number
 from typing import Dict, List
 
 from pydantic import BaseModel, root_validator
 
 from .. import Annotation, ResponseObject
+from ..base.utils import to_camel
 
 
 class TextsResponseObject(BaseModel):
     """
     Object representing a structured piece of text. Recursive.
-
-    Attributes
-    ----------
-    role: (str, optional) the role of this node in the response
-    content:(str, optional) string of translated/transcribed text
-    texts: (List[TextsResponseObject], optional) list of same structures, recursive
-    score: (int, optional) confidence of response
-    features (dict, optional): arbitrary JSON metadata about content
-    annotations (Dict[str, List[Annotation]], optional): optional annotations on request
     """
 
     role: str = None
+    """*(optional)* the role of this node in the response"""
+
     content: str = None
+    """*(optional)* string of translated/transcribed text"""
+
     texts: List = None
-    score: int = None
+    """*(optional)* list of same structures, recursive"""
+
+    score: Number = None
+    """*(optional)* confidence of response"""
+
     features: dict = None
+    """*(optional)* arbitrary JSON metadata about content"""
+
     annotations: Dict[str, List[Annotation]] = None
+    """*(optional)* optional annotations on request"""
+
+    class Config:
+        alias_generator = to_camel
+        arbitrary_types_allowed = True
 
     @root_validator()
     def either_content_or_text(cls, values):
-        """ "
-        validator: ensures either the "content" or "text" fields are present
         """
-        content, texts, score = values.get("content"), values.get("texts"), values.get("score")
+        *(validator)* ensures either the \"content\" or \"text\" fields are present
+        """
+        content, texts, score = (
+            values.get("content"),
+            values.get("texts"),
+            values.get("score"),
+        )
         if content is None and texts is None:
             raise ValueError('A text response must have either "content" or "texts" fields')
         if texts and score:
@@ -57,19 +69,17 @@ class TextsResponseObject(BaseModel):
 class TextsResponse(ResponseObject):
     """
     Response consisting of a set of one or more new texts, each with optional annotations attached to it.
+    Subclass of :class:`elg.model.base.ResponseObject.ResponseObject`
 
     For example a set of possible translations produced by a translation tool or possible transcriptions produced by a
     speech-to-text recogniser.
-
-    Attributes
-    ----------
-    type (str, required): type of response
-    warnings (List[StatusMessage], optional): messages describing any warnings on responses
-    texts (List[TextsResponseObject], optional): list of objects representing a structured text response
     """
 
     type: str = "texts"
+    """*(optional)* type of response, must be \"texts\""""
+
     texts: List[TextsResponseObject]
+    """*(optional)* list of objects representing a structured text response"""
 
     def auto_content(self):
         if self.warnings is not None:
