@@ -33,29 +33,29 @@ class ProcessingError(Exception):
         self.standard_message = standard_message
 
     @staticmethod
-    def InternalError(text):
-        return ProcessingError(500, StandardMessages.generate_elg_service_internalerror(params=[text]))
+    def InternalError(text, detail={}):
+        return ProcessingError(500, StandardMessages.generate_elg_service_internalerror(params=[text], detail=detail))
 
     @staticmethod
-    def InvalidRequest():
-        return ProcessingError(400, StandardMessages.generate_elg_request_invalid())
+    def InvalidRequest(detail={}):
+        return ProcessingError(400, StandardMessages.generate_elg_request_invalid(detail=detail))
 
     @staticmethod
-    def TooLarge():
-        return ProcessingError(413, StandardMessages.generate_elg_request_too_large())
+    def TooLarge(detail={}):
+        return ProcessingError(413, StandardMessages.generate_elg_request_too_large(detail=detail))
 
     @staticmethod
-    def UnsupportedMime(mime):
+    def UnsupportedMime(mime, detail={}):
         return ProcessingError(
             400,
-            StandardMessages.generate_elg_request_text_mimetype_unsupported(params=[mime]),
+            StandardMessages.generate_elg_request_text_mimetype_unsupported(params=[mime], detail=detail),
         )
 
     @staticmethod
-    def UnsupportedType(request_type):
+    def UnsupportedType(request_type, detail={}):
         return ProcessingError(
             400,
-            StandardMessages.generate_elg_request_type_unsupported(params=[request_type]),
+            StandardMessages.generate_elg_request_type_unsupported(params=[request_type], detail=detail),
         )
 
     def to_json(self):
@@ -339,11 +339,20 @@ class QuartService:
 
         logger.debug("Data type: {request_type}", request_type=data.get("type"))
         if data.get("type") == "audio":
-            request = AudioRequest(**data)
+            try:
+                request = AudioRequest(**data)
+            except Exception as e:
+                raise ProcessingError.InvalidRequest()
         elif data.get("type") == "text":
-            request = TextRequest(**data)
+            try:
+                request = TextRequest(**data)
+            except Exception as e:
+                raise ProcessingError.InvalidRequest()
         elif data.get("type") == "structuredText":
-            request = StructuredTextRequest(**data)
+            try:
+                request = StructuredTextRequest(**data)
+            except Exception as e:
+                raise ProcessingError.InvalidRequest()
         else:
             raise ProcessingError.InvalidRequest()
         logger.trace("Call with the input: {request}", request=request)
