@@ -16,7 +16,7 @@ import requests
 
 from .authentication import (ONE_HUNDRED_YEARS_IN_SECONDS, Authentication,
                              NeedAuthentication, need_authentication)
-from .entity import Entity
+from .entity import Entity, MetadataRecordObj
 from .model import (AudioRequest, Request, StructuredTextRequest, TextRequest,
                     get_response)
 from .utils import (MIME, get_argument_from_json, get_domain, get_information,
@@ -153,7 +153,16 @@ class Service(Entity, NeedAuthentication):
             use_cache=use_cache,
             cache_dir=cache_dir,
         )
-        self._get_elg_execution_location()
+        self.elg_execution_location_sync = get_information(
+            id=self.id,
+            obj=self.record,
+            infos=["service_info", "elg_execution_location_sync"],
+        )
+        self.elg_execution_location = get_information(
+            id=self.id,
+            obj=self.record,
+            infos=["service_info", "elg_execution_location"],
+        )
 
     @classmethod
     def from_id(
@@ -165,6 +174,8 @@ class Service(Entity, NeedAuthentication):
         domain: str = None,
         use_cache: bool = True,
         cache_dir: str = "~/.cache/elg",
+        local: bool = False,
+        local_domain: str = "http://localhost:8080/execution",
     ):
         """
         Class method to init a Service class from its id. You can provide authentication information through the
@@ -205,14 +216,40 @@ class Service(Entity, NeedAuthentication):
                     "domain argument you put."
                 )
             domain = auth_domain
+        # Create a dummy Authentication object if local
+        if local:
+            auth_object = Authentication(domain=local_domain)
+            auth_object.expires_time = time.gmtime(time.time() + ONE_HUNDRED_YEARS_IN_SECONDS)
+            auth_object.refresh_expires_time = time.gmtime(time.time() + ONE_HUNDRED_YEARS_IN_SECONDS)
+            use_cache = False
+            cache_dir = None
         # Use "live" domain by default
         domain = get_domain(domain=domain if domain is not None else "live")
         record = get_metadatarecord(id=id, domain=domain, use_cache=use_cache, cache_dir=cache_dir)
+        if local:
+            record["service_info"]["elg_execution_location_sync"] = (
+                get_information(
+                    id=id,
+                    obj=record,
+                    infos=["service_info", "elg_execution_location_sync"],
+                )
+                .replace("/execution", "")
+                .replace(domain, local_domain)
+            )
+            record["service_info"]["elg_execution_location"] = (
+                get_information(
+                    id=id,
+                    obj=record,
+                    infos=["service_info", "elg_execution_location"],
+                )
+                .replace("/execution", "")
+                .replace(domain, local_domain)
+            )
         result = map_metadatarecord_to_result(id=id, record=record)
         result["auth_object"] = auth_object
         result["auth_file"] = auth_file
         result["scope"] = scope
-        result["domain"] = domain
+        result["domain"] = domain if not local else local_domain
         result["use_cache"] = use_cache
         result["cache_dir"] = cache_dir
         return cls(**result)
@@ -245,7 +282,7 @@ class Service(Entity, NeedAuthentication):
         Returns:
             elg.Service: Service object with authentication information.
         """
-        if not entity.elg_compatible_service:
+        if not entity.functional_service:
             raise NotElgServiceException(entity.id)
         if entity.record == None:
             entity.record = get_metadatarecord(
@@ -263,44 +300,34 @@ class Service(Entity, NeedAuthentication):
         return cls(**parameters)
 
     @classmethod
-    def from_docker_image(
+    def from_local_installation(
         cls,
-        image: str,
-        execution_location: str,
-        port: int = 8000,
+        name: str,
+        local_domain: str = "http://localhost:8080/execution",
     ):
         """
         Class method to init a Service class from a Docker image ELG compatible.
 
         Args:
-            image (str): name of the Docker image ELG compatible
-            execution_location (str): url of the ELG compatible endpoint, e.g., `http://localhost:8000/process`.
-            port (int, optional): port to use locally. Defaults to 8000.
+            name (str): name of the service. Corresponds to the name of the service in the docker-compose.yml file.
+            local_domain (str, optional): endpoint of the LT service execution server deployed locally. Defaults to "http://localhost:8080/execution".
 
         Returns:
             elg.Service: Service object with authentication information.
         """
-        execution_location = urlparse(execution_location)
-        image_port = execution_location.port
-        image_port = int(image_port) if image_port is not None else 80
-        print(
-            "To call the service locally, the docker image needs to be running. ",
-            f"Please run the following command: `docker run -p {port}:{image_port} {image}`.",
-            "When calling the service, you need to set the `sync_mode` parameter to True, otherwise an error will be raised.",
-        )
         auth_object = Authentication(domain="local")
         auth_object.expires_time = time.gmtime(time.time() + ONE_HUNDRED_YEARS_IN_SECONDS)
         auth_object.refresh_expires_time = time.gmtime(time.time() + ONE_HUNDRED_YEARS_IN_SECONDS)
         record = {
             "service_info": {
-                "elg_execution_location_sync": f"http://127.0.0.1:{port}{execution_location.path}",
-                "elg_execution_location": "None",
+                "elg_execution_location_sync": f"{local_domain}/process/{name}",
+                "elg_execution_location": f"{local_domain}/async/process/{name}",
             }
         }
         parameters = {
             "id": 0,
-            "resource_name": image,
-            "resource_short_name": image,
+            "resource_name": name,
+            "resource_short_name": name,
             "resource_type": "ToolService",
             "entity_type": None,
             "description": None,
@@ -330,21 +357,6 @@ class Service(Entity, NeedAuthentication):
         }
         return cls(**parameters)
 
-    def _get_elg_execution_location(self):
-        """
-        Method to get the elg execution location information from the metadata record.
-        """
-        self.elg_execution_location_sync = get_information(
-            id=self.id,
-            obj=self.record,
-            infos=["service_info", "elg_execution_location_sync"],
-        )
-        self.elg_execution_location = get_information(
-            id=self.id,
-            obj=self.record,
-            infos=["service_info", "elg_execution_location"],
-        )
-
     @need_authentication()
     def __call__(
         self,
